# Minifold

[![PyPI](https://img.shields.io/pypi/v/minifold.svg)](https://pypi.python.org/pypi/minifold/)
[![Build](https://github.com/nokia/minifold/workflows/build/badge.svg)](https://github.com/nokia/minifold/actions/workflows/build.yml)
[![Documentation](https://github.com/nokia/minifold/workflows/docs/badge.svg)](https://github.com/nokia/minifold/actions/workflows/docs.yml)
[![ReadTheDocs](https://readthedocs.org/projects/minifold/badge/?version=latest)](https://minifold.readthedocs.io/en/)
[![codecov](https://codecov.io/gh/nokia/minifold/branch/master/graph/badge.svg?token=OZM4J0Y2VL)](https://codecov.io/gh/nokia/minifold)

## Overview

[Minifold](https://github.com/nokia/minifold.git) is a [Python](http://python.org/) module able to interact with various data sources (e.g. CSV, LDAP, SQL, twitter, etc.) and to query/combine/aggregate them with database-like operators.

## Use cases

This framework has been in various Nokia projects. It also used in the [LINCS](https://www.lincs.fr) website to generate:

* [trombinoscope](https://www.lincs.fr/people/)
* [homepages](https://www.lincs.fr/people/?more=marc_olivier_buob)
* [co-author graph](https://www.lincs.fr/research/lincs-graph/), thanks to [pyBGL](https://github.com/nokia/pybgl.git) and [GraphViz](http://graphviz.org/)

For more information, feel free to visit the [wiki](https://github.com/nokia/minifold/wiki):

* [Overview](https://github.com/nokia/minifold/wiki/Overview)
* [Installation](https://github.com/nokia/minifold/wiki/Installation)
* [Tutorial](https://github.com/nokia/minifold/wiki/Tutorial)
* [Design](https://github.com/nokia/minifold/wiki/Design)
* [Configuration](https://github.com/nokia/minifold/wiki/Configuration)
* [Framework](https://github.com/nokia/minifold/wiki/Framework)
* [Tests](https://github.com/nokia/minifold/wiki/Tests)
* [Packaging](https://github.com/nokia/minifold/wiki/Packaging)

# License

This project is licensed under the BSD-3-Clause license - see the [LICENSE](https://github.com/nokia/minifold/blob/master/LICENSE).
